@@ -553,6 +553,9 @@ class PluginAPI(Protocol):
 
 # base plugin
 class BasePlugin(ABC):
+    def __init__(self, logger: PluginLogger, api: PluginAPI) -> None:
+        pass
+
     @abstractmethod
     async def on_form_submit(self, action_id: str, payload: Any) -> Optional[dict]:
         pass
@@ -560,5 +563,5 @@ class BasePlugin(ABC):
     @abstractmethod
     def configure_cameras(
         self, cameras: List[Any]
-    ) -> None:  # todo: replace Any with Camera Device
+    ) -> None:  # todo: replace with Camera Device
         pass
